==> nextcloud-27.1.2.tgz: nextcloud/apps/files_reminders/l10n/uk.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Нагадування для файлів",
    "Reminder for {name}" : "Нагадування для {name}",
    "View file" : "Переглянути файл",
    "View folder" : "Переглянути каталог",
    "Set file reminders" : "Встановити нагадування для файлу",
    "**📣 File reminders**\n\nSet file reminders." : "**📣 Нагадування для файлів**\n\nВстановити нагадування для файлу.",
    "Back" : "Назад",
    "Clear reminder" : "Зняти нагадування",
    "Set custom reminder" : "Встановити власне нагадування",
    "Later today" : "Пізніше сьогодні",
    "Set reminder for later today" : "Встановити нагадування на сьогодні пізніше",
    "Tomorrow" : "Завтра",
    "Set reminder for tomorrow" : "Встановити нагадування на завтра",
    "This weekend" : "Цими вихідними",
    "Set reminder for this weekend" : "Встановити нагадування на ці вихідні",
    "Next week" : "Наступний тиждень",
    "Set reminder for next week" : "Встановити нагадування на наступний тиждень",
    "Set reminder at custom date & time" : "Встановити нагадування на власну дату та час",
    "Reminder set for \"{fileName}\"" : "Встановлено нагадування для \"{fileName}\"",
    "Failed to set reminder" : "Не вдалося встановити нагадування",
    "Please choose a valid date & time" : "Виберіть дійсні дату та час",
    "Reminder cleared" : "Нагадування знято",
    "Failed to clear reminder" : "Не вдалося зняти нагадування",
    "Failed to load reminder" : "Не вдалося отримати нагадування"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");

==> nextcloud-28.0.3.tgz: nextcloud/apps/files_reminders/l10n/uk.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Нагадування для файлів",
    "Reminder for {name}" : "Нагадування для {name}",
    "View file" : "Переглянути файл",
    "View folder" : "Переглянути каталог",
    "Set file reminders" : "Встановити нагадування для файлу",
    "**📣 File reminders**\n\nSet file reminders." : "**📣 Нагадування для файлів**\n\nВстановити нагадування для файлу.",
    "We will remind you of this file" : "Ми нагадаємо вам про цей файл.",
    "Please choose a valid date & time" : "Виберіть дійсні дату та час",
    "Cancel" : "Відміна",
    "Set reminder" : "Встановити нагадування",
    "Set reminder for \"{fileName}\"" : "Встановити нагадування для \"{fileName}\"",
    "Set reminder at custom date & time" : "Встановити нагадування на власну дату та час",
    "Clear reminder" : "Зняти нагадування",
    "Reminder set for \"{fileName}\"" : "Встановлено нагадування для \"{fileName}\"",
    "Failed to set reminder" : "Не вдалося встановити нагадування",
    "Set custom reminder" : "Встановити власне нагадування",
    "Later today" : "Пізніше сьогодні",
    "Set reminder for later today" : "Встановити нагадування на сьогодні пізніше",
    "Tomorrow" : "Завтра",
    "Set reminder for tomorrow" : "Встановити нагадування на завтра",
    "This weekend" : "Цими вихідними",
    "Set reminder for this weekend" : "Встановити нагадування на ці вихідні",
    "Next week" : "Наступний тиждень",
    "Set reminder for next week" : "Встановити нагадування на наступний тиждень",
    "Back" : "Назад",
    "Reminder cleared" : "Нагадування знято",
    "Failed to clear reminder" : "Не вдалося зняти нагадування",
    "Failed to load reminder" : "Не вдалося отримати нагадування"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
